==> apache-streampark-2.0.0-incubating-src.tar.gz: apache-streampark-2.0.0-incubating-src/streampark-spark/streampark-spark-core/src/main/scala/org/apache/streampark/spark/core/serializable/MultipleOutputer.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.streampark.spark.core.serializable

import org.apache.avro.mapreduce.AvroMultipleOutputs
import org.apache.hadoop.mapreduce.lib.output.MultipleOutputs

/**
 * Multiple dir output
 *
 * @tparam K key
 * @tparam V value
 */
trait MultipleOutputer[K, V] {
  def write(key: K, value: V, path: String): Unit

  def close(): Unit
}

object MultipleOutputer {

  /**
   * Avro multi files output
   *
   * @param mo
   * @tparam K
   * @tparam V
   */
  implicit class AvroMultipleOutputer[K, V](mo: AvroMultipleOutputs) extends MultipleOutputer[K, V] {
    def write(key: K, value: V, path: String): Unit = mo.write(key, value, path)

    def close(): Unit = mo.close()
  }

  /**
   * Unformatted multipath output
   *
   * @param mo
   * @tparam K
   * @tparam V
   */
  implicit class PlainMultipleOutputer[K, V](mo: MultipleOutputs[K, V]) extends MultipleOutputer[K, V] {
    def write(key: K, value: V, path: String): Unit = mo.write(key, value, path)

    def close(): Unit = mo.close()
  }

}

==> apache-streampark-2.1.3-incubating-src.tar.gz: apache-streampark-2.1.3-incubating-src/streampark-spark/streampark-spark-core/src/main/scala/org/apache/streampark/spark/core/serializable/MultipleOutputer.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.streampark.spark.core.serializable

import org.apache.avro.mapreduce.AvroMultipleOutputs
import org.apache.hadoop.mapreduce.lib.output.MultipleOutputs

/**
 * Multiple dir output
 *
 * @tparam K
 *   key
 * @tparam V
 *   value
 */
trait MultipleOutputer[K, V] {
  def write(key: K, value: V, path: String): Unit

  def close(): Unit
}

object MultipleOutputer {

  /**
   * Avro multi files output
   *
   * @param mo
   * @tparam K
   * @tparam V
   */
  implicit class AvroMultipleOutputer[K, V](mo: AvroMultipleOutputs)
    extends MultipleOutputer[K, V] {
    def write(key: K, value: V, path: String): Unit = mo.write(key, value, path)

    def close(): Unit = mo.close()
  }

  /**
   * Unformatted multipath output
   *
   * @param mo
   * @tparam K
   * @tparam V
   */
  implicit class PlainMultipleOutputer[K, V](mo: MultipleOutputs[K, V])
    extends MultipleOutputer[K, V] {
    def write(key: K, value: V, path: String): Unit = mo.write(key, value, path)

    def close(): Unit = mo.close()
  }

}
